@@ -136,3 +136,6 @@ dtm <- dtm_remove_lowfreq(dtm, minfreq = 3)
 m <- LDA(dtm, k = 3, method = "Gibbs", 
          control = list(nstart = 5, burnin = 2000, best = TRUE, seed = 1:5))
 
+## ---- results='hide', echo=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+invisible(file.remove(c("french-gsd-ud-2.3-181115.udpipe")))
+
